@@ -33,8 +33,8 @@ archmCopula <- function(family, param = NA_real_, dim = 2L, ...) {
 
 
 tauArchmCopula <- function(copula) {
-  integrand <- function(x) iPsi(copula, x) / diPsi(copula, x)
-  1 + 4 * integrate(integrand, 0, 1)$value
+  1 + 4 * integrate(function(x) iPsi(copula, x) / diPsi(copula, x),
+                    0, 1)$value
 }
 
 setMethod("tau", signature("archmCopula"), tauArchmCopula)
