@@ -90,7 +90,7 @@ signFF <- function(alpha, j, d) {
 lsum <- function(lx, l.off = apply(lx, 2, max)) {
     ## do not use cbind or rbind here, since it is not clear if the user specified
     ## only one vector log(x) or several vectors of dimension 1 !!!
-    stopifnot(length(dim(lx)) == 2L) # is.matrix(.) generalized
+    ## stopifnot(length(dim(lx)) == 2L) # is.matrix(.) generalized
     l.off + log(colSums(exp(lx - rep(l.off, each=nrow(lx)))))
 }
 
@@ -533,7 +533,7 @@ Bernoulli.all <-
            ii <- seq_len((n-1L) %/% 2)
            B[ii*2L] <- get("Bern.tab", .nacopEnv)[[method]][ii]
        },
-           stop(sprintf("method '%s' not yet implemented", method))
+           stop(gettextf("method '%s' not yet implemented", method), domain=NA)
            )## end{switch}
     B
 }
@@ -589,7 +589,7 @@ Bernoulli <- function(n, method = c("sumBin", "sumRamanujan", "asymptotic"),
 		   Btab[[method]][n2] <- B
 		   assign("Bern.tab", Btab, envir = .nacopEnv)
 	       },
-		   stop(sprintf("method '%s' not yet implemented", method))
+		   stop(gettextf("method '%s' not yet implemented", method), domain=NA)
 		   )## end{switch}
 	}
 	B
